@@ -9,24 +9,24 @@
 
 Error& Errors::_InternalError()
 {
-    static Error *error = 0;
-    if (error == 0)
+    static Error  *error = nullptr;
+    if (error == nullptr)
         error = new Error(1, -1, i18n("Internal Error"));
     return *error;
 }
 
 Error &Errors::_SyntaxError()
 {
-    static Error *error = 0;
-    if (error == 0)
+    static Error  *error = nullptr;
+    if (error == nullptr)
         error = new Error(2, -1, i18n("Syntax Error before '%1'"));
     return *error;
 }
 
 Error &Errors::_ParseError()
 {
-    static Error *error = 0;
-    if (error == 0)
+    static Error  *error = nullptr;
+    if (error == nullptr)
         error = new Error(3, -1, i18n("Parse Error before '%1'"));
     return *error;
 }
