@@ -25,7 +25,7 @@ class PhpDocsModel : public QAbstractListModel
     Q_OBJECT
 
 public:
-    explicit PhpDocsModel(QObject* parent = 0);
+    explicit PhpDocsModel(QObject *parent = nullptr);
     ~PhpDocsModel();
 
     enum CustomDataRoles {
@@ -59,7 +59,7 @@ private:
     /// internal function file
     const KDevelop::IndexedString m_internalFunctionsFile;
 
-public slots:
+public Q_SLOTS:
     void updateReady( const KDevelop::IndexedString& url, const KDevelop::ReferencedTopDUContext& topContext );
 
 };
