@@ -12,16 +12,16 @@
 #include "umldragdata.h"
 #include "idchangelog.h"
 #include "associationwidget.h"
-#include "attribute.h"
-#include "classifier.h"
-#include "enum.h"
-#include "entity.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
+#include "umlenum.h"
+#include "umlentity.h"
 #include "floatingtextwidget.h"
 #include "messagewidget.h"
-#include "operation.h"
-#include "template.h"
-#include "enumliteral.h"
-#include "entityattribute.h"
+#include "umloperation.h"
+#include "umltemplate.h"
+#include "umlenumliteral.h"
+#include "umlentityattribute.h"
 #include "model_utils.h"
 #include "notewidget.h"
 #include "umldoc.h"
@@ -31,7 +31,7 @@
 #include "umlscene.h"
 #include "umlview.h"
 #include "umlwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <KMessageBox>
@@ -70,27 +70,27 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
     m_ObjectList.clear();
     m_ViewList.clear();
 
-    UMLDragData *data = 0;
-    QPixmap* png = 0;
+    UMLDragData  *data = nullptr;
+    QPixmap *png = nullptr;
 
     UMLListView * listView = UMLApp::app()->listView();
 
     if (fromView) {
         m_type = clip4;
         UMLView *view = UMLApp::app()->currentView();
-        if (view == 0) {
+        if (view == nullptr) {
             logError0("UMLApp::app()->currentView() is NULL");
-            return 0;
+            return nullptr;
         }
         UMLScene *scene = view->umlScene();
-        if (scene == 0) {
+        if (scene == nullptr) {
             logError0("UMLClipboard::copy: currentView umlScene() is NULL");
-            return 0;
+            return nullptr;
         }
         m_WidgetList = scene->selectedWidgetsExt();
         //if there is no selected widget then there is no copy action
         if (!m_WidgetList.count()) {
-            return 0;
+            return nullptr;
         }
         m_AssociationList = scene->selectedAssocs();
         scene->copyAsImage(png);
@@ -104,8 +104,8 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
         // instance.
         fillObjectListForWidgets(m_WidgetList);
 
-        foreach (WidgetBase* widget, m_AssociationList) {
-            if (widget->umlObject() != 0) {
+        for(WidgetBase *widget : m_AssociationList) {
+            if (widget->umlObject() != nullptr) {
                 m_ObjectList.append(widget->umlObject());
             }
         }
@@ -113,7 +113,7 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
         // The copy action is being performed from the ListView
         UMLListViewItemList itemsSelected = listView->selectedItems();
         if (itemsSelected.count() <= 0) {
-            return 0;
+            return nullptr;
         }
 
         // Set What type of copy operation are we performing and
@@ -124,17 +124,17 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
         // on the ListView that correspond to a UseCase, Actor or Concept
         // in the Diagram
         if (m_type == clip2) {
-            foreach (UMLView* view, m_ViewList) {
+            for(UMLView* view : m_ViewList) {
                 UMLScene *scene = view->umlScene();
-                if (scene == 0) {
+                if (scene == nullptr) {
                     logError0("UMLClipboard::copy: currentView umlScene() is NULL");
                     continue;
                 }
                 fillObjectListForWidgets(scene->widgetList());
 
                 AssociationWidgetList associations = scene->associationList();
-                foreach (AssociationWidget* association, associations) {
-                    if (association->umlObject() != 0) {
+                for(AssociationWidget* association : associations) {
+                    if (association->umlObject() != nullptr) {
                         m_ObjectList.append(association->umlObject());
                     }
                 }
@@ -143,11 +143,11 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
             // Clip1, 4 and 5: fill the clip with only the specific objects
             // selected in the list view
             if (!fillSelectionLists(itemsSelected)) {
-                return 0;
+                return nullptr;
             }
 
             if (itemsSelected.count() <= 0) {
-                return 0;
+                return nullptr;
             }
         }
     }
@@ -169,7 +169,7 @@ QMimeData* UMLClipboard::copy(bool fromView/*=false*/)
             data = new UMLDragData(m_ObjectList, m_WidgetList,
                                    m_AssociationList, *png, view->umlScene());
         } else {
-            return 0;
+            return nullptr;
         }
         break;
     case clip5:
@@ -234,9 +234,9 @@ bool UMLClipboard::paste(const QMimeData* data)
 void UMLClipboard::addRelatedWidgets()
 {
     UMLWidgetList relatedWidgets;
-    UMLWidget *pWA =0, *pWB = 0;
+    UMLWidget   *pWA = nullptr, *pWB = nullptr;
 
-    foreach (UMLWidget* widget, m_WidgetList) {
+    for(UMLWidget* widget : m_WidgetList) {
         if (widget->isMessageWidget()) {
             MessageWidget * pMessage = widget->asMessageWidget();
             pWA = (UMLWidget*)pMessage->objectWidget(Uml::RoleType::A);
@@ -248,7 +248,7 @@ void UMLClipboard::addRelatedWidgets()
         }
     }
 
-    foreach(AssociationWidget *pAssoc, m_AssociationList) {
+    for(AssociationWidget *pAssoc : m_AssociationList) {
         pWA = pAssoc->widgetForRole(Uml::RoleType::A);
         pWB = pAssoc->widgetForRole(Uml::RoleType::B);
         if (!relatedWidgets.contains(pWA))
@@ -257,7 +257,7 @@ void UMLClipboard::addRelatedWidgets()
             relatedWidgets.append(pWB);
     }
 
-    foreach(UMLWidget *widget, relatedWidgets) {
+    for(UMLWidget *widget : relatedWidgets) {
         if (!m_WidgetList.contains(widget))
             m_WidgetList.append(widget);
     }
@@ -274,18 +274,18 @@ void UMLClipboard::fillObjectListForWidgets(const UMLWidgetList& widgets)
     // the packages and add them from the root package to the deeper levels
     UMLObjectList packages;
 
-    foreach (UMLWidget* widget, widgets) {
+    for(UMLWidget* widget : widgets) {
         UMLObject* widgetObject = widget->umlObject();
-        if (widgetObject != 0) {
+        if (widgetObject != nullptr) {
             packages.clear();
 
             UMLPackage* package = widgetObject->umlPackage();
-            while (package != 0) {
+            while (package != nullptr) {
                 packages.prepend(package);
                 package = package->umlPackage();
             }
 
-            foreach (UMLObject* package, packages) {
+            for(UMLObject *package : packages) {
                 if (!m_ObjectList.contains(package)) {
                     m_ObjectList.append(package);
                 }
@@ -310,7 +310,7 @@ bool UMLClipboard::fillSelectionLists(UMLListViewItemList& selectedItems)
     case clip4:
         break;
     case clip3:
-        foreach (UMLListViewItem* item, selectedItems) {
+        for(UMLListViewItem *item : selectedItems) {
             type = item->type();
             if (!Model_Utils::typeIsClassifierList(type)) {
                 m_ItemList.append(item);
@@ -320,7 +320,7 @@ bool UMLClipboard::fillSelectionLists(UMLListViewItemList& selectedItems)
         break;
     case clip2:
     case clip1:
-        foreach (UMLListViewItem* item, selectedItems) {
+        for(UMLListViewItem *item : selectedItems) {
             type = item->type();
             if (!Model_Utils::typeIsClassifierList(type)) {
                 if (Model_Utils::typeIsCanvasWidget(type)) {
@@ -334,7 +334,7 @@ bool UMLClipboard::fillSelectionLists(UMLListViewItemList& selectedItems)
         }
         break;
     case clip5:
-        foreach (UMLListViewItem* item, selectedItems) {
+        for(UMLListViewItem *item : selectedItems) {
             type = item->type();
             if(Model_Utils::typeIsClassifierList(type)) {
                 m_ObjectList.append(item->umlObject());
@@ -360,7 +360,7 @@ void UMLClipboard::setCopyType(UMLListViewItemList& selectedItems)
     bool withObjects = false; //If the selection includes objects
     bool onlyAttsOps = false; //If the selection only includes Attributes and/or Operations
 
-    foreach (UMLListViewItem* item, selectedItems) {
+    for(UMLListViewItem *item : selectedItems) {
         checkItemForCopyType(item, withDiagrams, withObjects, onlyAttsOps);
     }
     if (onlyAttsOps) {
@@ -390,8 +390,8 @@ void UMLClipboard::checkItemForCopyType(UMLListViewItem* item, bool & withDiagra
     }
     UMLDoc *doc = UMLApp::app()->document();
     onlyAttsOps = true;
-    UMLView * view = 0;
-    UMLListViewItem * child = 0;
+    UMLView  *view = nullptr;
+    UMLListViewItem  *child = nullptr;
     UMLListViewItem::ListViewType type = item->type();
     if (Model_Utils::typeIsCanvasWidget(type)) {
         withObjects = true;
@@ -472,9 +472,9 @@ bool UMLClipboard::pasteClip2(const QMimeData* data)
     }
 
     if (NoteWidget::s_pCurrentNote) {
-        NoteWidget::s_pCurrentNote = 0;
+        NoteWidget::s_pCurrentNote = nullptr;
     } else {
-        foreach (UMLView* pView, views) {
+        for(UMLView *pView : views) {
             if (!doc->addUMLView(pView)) {
                 return false;
             }
@@ -526,7 +526,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
     UMLWidgetList widgets;
     AssociationWidgetList assocs;
 
-    IDChangeLog* idchanges = 0;
+    IDChangeLog *idchanges = nullptr;
 
     Uml::DiagramType::Enum diagramType;
 
@@ -542,7 +542,8 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
     }
      //make sure the file we are pasting into has the objects
      //we need if there are widgets to be pasted
-    foreach (UMLObject* obj, objects) {
+    for(UMLObject *obj : objects) {
+        uIgnoreZeroPointer(obj);
         if(!doc->assignNewIDs(obj)) {
             return false;
         }
@@ -553,7 +554,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
     bool objectAlreadyExists = false;
     currentScene->beginPartialWidgetPaste();
 
-    foreach (UMLWidget* widget, widgets) {
+    for(UMLWidget *widget : widgets) {
 
         Uml::ID::Type oldId = widget->id();
         Uml::ID::Type newId = idchanges->findNewID(oldId);
@@ -572,7 +573,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
     }
 
     //now paste the associations
-    foreach (AssociationWidget* assoc, assocs) {
+    for(AssociationWidget *assoc : assocs) {
         if (!currentScene->addAssociation(assoc, true)) {
             currentScene->endPartialWidgetPaste();
             return false;
@@ -581,7 +582,7 @@ bool UMLClipboard::pasteClip4(const QMimeData* data)
 
     currentScene->clearSelected();
     currentScene->selectWidgets(widgets);
-    foreach (AssociationWidget* assoc, assocs) {
+    for(AssociationWidget *assoc : assocs) {
         currentScene->selectWidgetsOfAssoc(assoc);
     }
 
@@ -611,14 +612,14 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
     }
     UMLClassifier *parent = lvitem->umlObject()->asUMLClassifier();
 
-    if (parent == 0) {
+    if (parent == nullptr) {
         logError0("UMLClipboard::pasteClip5: parent is not a UMLClassifier");
         return false;
     }
 
     UMLObjectList objects;
 
-    IDChangeLog* idchanges = 0;
+    IDChangeLog *idchanges = nullptr;
     bool result = UMLDragData::decodeClip5(data, objects, parent);
 
     if(!result) {
@@ -631,7 +632,8 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
     if (objects.count())
         result = false;
 
-    foreach (UMLObject* obj, objects) {
+    for(UMLObject *obj : objects) {
+        uIgnoreZeroPointer(obj);
         obj->setID(doc->assignNewID(obj->id()));
         switch(obj->baseType()) {
         case UMLObject::ot_Attribute :
@@ -653,7 +655,7 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
         case UMLObject::ot_Operation :
             {
                 UMLOperation *op = obj->asUMLOperation();
-                UMLOperation *exist = parent->checkOperationSignature(op->name(), op->getParmList());
+                UMLOperation *exist = parent->checkOperationSignature(op->name(), op->getParameterList());
                 if (exist) {
                     QString newName = parent->uniqChildName(UMLObject::ot_Operation, obj->name());
                     op->setName(newName);
@@ -747,7 +749,7 @@ bool UMLClipboard::pasteClip5(const QMimeData* data)
 void UMLClipboard::pasteItemAlreadyExists()
 {
     UMLView *currentView = UMLApp::app()->currentView();
-    KMessageBox::sorry(currentView,
+    KMessageBox::information(currentView,
                         i18n("At least one of the items in the clipboard "
                              "could not be pasted because an item of the "
                              "same name already exists.  Any other items "
