@@ -9,13 +9,13 @@
 #include "ownedcodeblock.h"
 
 // local includes
-#include "association.h"
-#include "classifier.h"
+#include "umlassociation.h"
+#include "umlclassifier.h"
 #include "debug_utils.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlrole.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "textblock.h"
 
 // qt includes
