@@ -11,12 +11,11 @@
 // local includes
 #include "rubycodecomment.h"
 #include "codeviewerdialog.h"
-#include "uml.h"
+#include "umlapp.h"
 
 // kde includes
 #include <kconfig.h>
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 #include <QRegularExpression>
