@@ -14,15 +14,15 @@
 #define DBG_SRC QStringLiteral("CppImport")
 #include "debug_utils.h"
 #include "import_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umlobject.h"
-#include "package.h"
-#include "enum.h"
-#include "classifier.h"
-#include "operation.h"
-#include "attribute.h"
-#include "template.h"
-#include "association.h"
+#include "umlpackage.h"
+#include "umlenum.h"
+#include "umlclassifier.h"
+#include "umloperation.h"
+#include "umlattribute.h"
+#include "umltemplate.h"
+#include "umlassociation.h"
 #include "optionstate.h"
 
 // qt includes
