@@ -7,16 +7,16 @@
 #include "csvalaimportbase.h"
 
 // app includes
-#include "attribute.h"
-#include "classifier.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #include "codeimpthread.h"
 #define DBG_SRC QStringLiteral("CsValaImportBase")
 #include "debug_utils.h"
-#include "enum.h"
+#include "umlenum.h"
 #include "import_utils.h"
-#include "operation.h"
-#include "package.h"
-#include "uml.h"
+#include "umloperation.h"
+#include "umlpackage.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlpackagelist.h"
 
@@ -337,7 +337,7 @@ bool CsValaImportBase::parseNamespaceDeclaration()
 bool CsValaImportBase::parseAnnotation()
 {
     QString token, annotation;
-    while ((token = advance()) != "]" && !token.isEmpty()) {
+    while ((token = advance()) != QStringLiteral("]") && !token.isEmpty()) {
         annotation.append(token);
     }
     log(QStringLiteral("attribute ") + annotation);
