@@ -9,11 +9,11 @@
 #include "cpptree2uml.h"
 
 // app includes
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umllistview.h"
-#include "datatype.h"
-#include "operation.h"
+#include "umldatatype.h"
+#include "umloperation.h"
 #define DBG_SRC QStringLiteral("CppTree2Uml")
 #include "debug_utils.h"
 #include "ast_utils.h"
@@ -23,9 +23,9 @@
 
 // FIXME: The sole reason for the next 2 includes is parseTypedef().
 // Make capsule methods in ClassImport, and remove these includes.
-#include "classifier.h"
+#include "umlclassifier.h"
 // FIXME The next include is motivated by template params
-#include "template.h"
+#include "umltemplate.h"
 
 // qt includes
 #include <QDir>
@@ -480,7 +480,7 @@ void CppTree2Uml::parseClassSpecifier(ClassSpecifierAST* ast)
 
     // check if class is an interface
     bool isInterface = true;
-    for(UMLOperation *op : klass->getOpList()) {
+    for(UMLOperation *op : klass->getOperationsList()) {
         if (!op->isDestructorOperation() && op->isAbstract() == false)
             isInterface = false;
     }
