@@ -7,20 +7,20 @@
 #include "phpimport.h"
 
 // app includes
-#include "artifact.h"
-#include "association.h"
-#include "attribute.h"
-#include "classifier.h"
+#include "umlartifact.h"
+#include "umlassociation.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
 #define DBG_SRC QStringLiteral("PHPImport")
 #include "debug_utils.h"
-#include "enum.h"
+#include "umlenum.h"
 #include "import_utils.h"
 #include "object_factory.h"
-#include "operation.h"
+#include "umloperation.h"
 #include "optionstate.h"
-#include "package.h"
-#include "template.h"
-#include "uml.h"
+#include "umlpackage.h"
+#include "umltemplate.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 
@@ -212,7 +212,7 @@ public:
         }
 
         m_nsCnt = 0;
-        foreach(const QString &nsName, nsNames) {
+        for(const QString &nsName : nsNames) {
             UMLPackage *parentPackage = m_currentNamespace[m_nsCnt];
             UMLObject *o = UMLApp::app()->document()->findUMLObject(nsName, UMLObject::ot_Package, parentPackage);
             if (!o)
@@ -241,7 +241,7 @@ public:
         }
 
         m_nsCnt = 0;
-        foreach(const QString &nsName, nsNames) {
+        for(const QString &nsName : nsNames) {
             UMLPackage *parentPackage = m_currentNamespace[m_nsCnt];
             UMLObject *o = UMLApp::app()->document()->findUMLObject(nsName, UMLObject::ot_Package, parentPackage);
             if (!o)
@@ -279,7 +279,7 @@ public:
                 it = it->next;
             } while (it != end);
         }
-        UMLPackage *parent = 0;
+        UMLPackage  *parent = nullptr;
         QString names = nsNames.join("::");
         UMLObject *o = UMLApp::app()->document()->findUMLObject(names, UMLObject::ot_Class, parent);
         if (!o)
@@ -312,7 +312,7 @@ public:
         QString m_comment;
         UMLPackage *parentPackage = m_currentNamespace[m_nsCnt];
         UMLClassifier *c = parentPackage->asUMLClassifier();
-        UMLOperation *m = 0;
+        UMLOperation  *m = nullptr;
         if (c) {
             m = Import_Utils::makeOperation(c, methodName);
         } else {
@@ -340,7 +340,7 @@ public:
         if (node->identifier) {
             QString baseName = tokenValue(node->identifier);
             UMLClassifier *a = m_currentNamespace[m_nsCnt]->asUMLClassifier();
-            foreach(UMLObject *uc, m_usingClasses) {
+            for(UMLObject  *uc : m_usingClasses) {
                 if (uc->name() == baseName) {
                     Import_Utils::createGeneralization(a, uc->asUMLClassifier());
                 }
@@ -355,7 +355,7 @@ public:
             QString baseName = tokenValue(node->implementsSequence);
             UMLClassifier *a = m_currentNamespace[m_nsCnt]->asUMLClassifier();
             bool found = false;
-            foreach(UMLObject *uc, m_usingClasses) {
+            for(UMLObject  *uc : m_usingClasses) {
                 if (uc->name() == baseName) {
                     Import_Utils::createGeneralization(a, uc->asUMLClassifier());
                     found = true;
@@ -436,7 +436,7 @@ public:
         QString m_comment;
         UMLPackage *parentPackage = m_currentNamespace[m_nsCnt];
         UMLClassifier *c = parentPackage->asUMLClassifier();
-        UMLOperation *m = 0;
+        UMLOperation  *m = nullptr;
         if (c) {
             m = Import_Utils::makeOperation(c, methodName);
         } else {
@@ -476,7 +476,7 @@ public:
             {
                 tokenString = m_content.mid(begin, 10);
                 tokenString += " ...";
-                tokenString += QString("%1 more").arg(end-begin-20);
+                tokenString += QStringLiteral("%1 more").arg(end-begin-20);
                 tokenString += "... ";
                 tokenString += m_content.mid(end-10, 10);
             }
@@ -621,10 +621,10 @@ private:
         }
         m_ast = 0;
         if (!m_session.parse(&m_ast)) {
-            qerr << "no AST tree could be generated" << endl;
+            qerr << "no AST tree could be generated" << QLatin1Char('\n');
             result = false;
         } else {
-            qout << "AST tree successfully generated" << endl;
+            qout << "AST tree successfully generated" << QLatin1Char('\n');
             if (m_printAst) {
                 DebugVisitorT debugVisitor(m_session.tokenStream(), m_session.contents());
                 debugVisitor.visitStart(m_ast);
@@ -639,8 +639,8 @@ private:
             includeFileVisitor.visitStart(m_ast);
         }
         if (!m_session.problems().isEmpty()) {
-            qout << endl << "problems encountered during parsing:" << endl;
-            foreach(KDevelop::ProblemPointer p, m_session.problems()) {
+            qout << QLatin1Char('\n') << "problems encountered during parsing:" << QLatin1Char('\n');
+            for(KDevelop::ProblemPointer p: m_session.problems()) {
                 QString item = QString::fromLatin1("%1:%2:%3: %4: %5")
                         .arg(fileName).arg(p->finalLocation().start().line()+1)
                         .arg(p->finalLocation().start().column())
@@ -648,7 +648,7 @@ private:
                 UMLApp::app()->log(item);
             }
         } else {
-            qout << "no problems encountered during parsing" << endl;
+            qout << "no problems encountered during parsing" << QLatin1Char('\n');
         }
         return result;
     }
@@ -694,12 +694,12 @@ public:
 
     bool parseFile(const QStringList &files)
     {
-        foreach(const QString &fileName, files) {
+        for(const QString &fileName: files) {
             PhpParser *parser = new PhpParser(m_printAst, m_printTokens);
             QFileInfo fi(fileName);
             parser->parseFile(fi.canonicalFilePath());
             m_parsers[fi.canonicalFilePath()] = parser;
-            foreach(const QString dependency, parser->dependencies()) {
+            for(const QString dependency: parser->dependencies()) {
                 QFileInfo di(dependency);
                 QFileInfo ei(di.isAbsolute() ? dependency : fi.canonicalPath() + "/" + dependency);
                 QString usePath = ei.canonicalFilePath();
@@ -728,7 +728,7 @@ public:
         if (!m_parsers.contains(f))
             return files;
         files.append(f);
-        foreach(const QString dependency, m_parsers[f]->dependencies()) {
+        for(const QString dependency: m_parsers[f]->dependencies()) {
             QFileInfo di(dependency);
             QFileInfo ei(di.isAbsolute() ? dependency : fi.canonicalPath() + "/" + dependency);
             QString path = ei.canonicalFilePath();
@@ -770,7 +770,7 @@ PHPImport::~PHPImport()
  */
 void PHPImport::feedTheModel(const QString& fileName)
 {
-    foreach(const QString &file, m_d->getParsedFiles(fileName)) {
+    for(const QString &file: m_d->getParsedFiles(fileName)) {
         PhpParser *p = m_d->m_parsers[file];
         Php::PHPImportVisitor visitor(p->tokenStream(), p->contents());
         visitor.setFileName(file);
