@@ -5,20 +5,20 @@
 
 #include "constraintlistpage.h"
 
-#include "attribute.h"
+#include "umlattribute.h"
 #include "debug_utils.h"
-#include "classifierlistitem.h"
-#include "classifier.h"
-#include "enum.h"
-#include "entity.h"
-#include "entityattribute.h"
-#include "enumliteral.h"
+#include "umlclassifierlistitem.h"
+#include "umlclassifier.h"
+#include "umlenum.h"
+#include "umlentity.h"
+#include "umlentityattribute.h"
+#include "umlenumliteral.h"
 #include "object_factory.h"
-#include "operation.h"
-#include "template.h"
+#include "umloperation.h"
+#include "umltemplate.h"
 #include "umldoc.h"
-#include "uml.h"  // only needed for log{Warn,Error}
-#include "uniqueconstraint.h"
+#include "umlapp.h"  // only needed for log{Warn,Error}
+#include "umluniqueconstraint.h"
 
 #include <KLocalizedString>
 #include <QMenu>
@@ -96,13 +96,13 @@ void ConstraintListPage::slotNewPrimaryKeyConstraint()
     // set the last object created as Primary Key
     UMLEntity* ent = m_pClassifier->asUMLEntity();
 
-    if (ent == 0) {
+    if (ent == nullptr) {
         logError0("ConstraintListPage::slotNewPrimaryKeyConstraint: Could not set Primary Key. "
                   "Entity Value is Null");
         return;
     }
 
-    if (m_pLastObjectCreated != 0) {
+    if (m_pLastObjectCreated != nullptr) {
         m_bSigWaiting = true;
         ent->setAsPrimaryKey(m_pLastObjectCreated->asUMLUniqueConstraint());
         m_itemType = UMLObject::ot_EntityConstraint;
