@@ -8,21 +8,21 @@
 
 //app includes
 #include "debug_utils.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
-#include "operation.h"
-#include "classifier.h"
-#include "template.h"
+#include "umloperation.h"
+#include "umlclassifier.h"
+#include "umltemplate.h"
 #include "dialogspopupmenu.h"
 #include "umlattributelist.h"
 #include "umldatatypewidget.h"
 #include "umlstereotypewidget.h"
-#include "classifierlistitem.h"
+#include "umlclassifierlistitem.h"
 #include "documentationwidget.h"
 #include "umlclassifierlistitemlist.h"
 #include "dialog_utils.h"
 #include "parameterpropertiesdialog.h"
-#include "stereotype.h"
+#include "umlstereotype.h"
 #include "uniqueid.h"
 #include "visibilityenumwidget.h"
 
@@ -183,7 +183,7 @@ void UMLOperationDialog::setupDialog()
     m_pDownButton->setEnabled(false);
 
     // fill in parm list box
-    UMLAttributeList list = m_operation->getParmList();
+    UMLAttributeList list = m_operation->getParameterList();
     for(UMLAttribute* pAtt : list) {
         m_pParmsLW->addItem(pAtt->toString(Uml::SignatureType::SigNoVis));
     }
@@ -269,11 +269,11 @@ void UMLOperationDialog::slotNewParameter()
 
     QPointer<ParameterPropertiesDialog> dlg = new ParameterPropertiesDialog(this, m_doc, newAttribute);
     if (dlg->exec()) {
-        pAtt = m_operation->findParm(newAttribute->name());
+        pAtt = m_operation->findParameter(newAttribute->name());
 
         if (!pAtt) {
             newAttribute->setID(UniqueID::gen());
-            m_operation->addParm(newAttribute);
+            m_operation->addParameter(newAttribute);
             m_pParmsLW->addItem(newAttribute->toString(Uml::SignatureType::SigNoVis));
             m_doc->setModified(true);
         } else {
@@ -289,9 +289,9 @@ void UMLOperationDialog::slotNewParameter()
 
 void UMLOperationDialog::slotDeleteParameter()
 {
-    UMLAttribute* pOldAtt = m_operation->getParmList().at(m_pParmsLW->row(m_pParmsLW->currentItem()));
+    UMLAttribute* pOldAtt = m_operation->getParameterList().at(m_pParmsLW->row(m_pParmsLW->currentItem()));
 
-    m_operation->removeParm(pOldAtt);
+    m_operation->removeParameter(pOldAtt);
     m_pParmsLW->takeItem(m_pParmsLW->currentRow());
     m_doc->setModified(true);
 
@@ -306,7 +306,7 @@ void UMLOperationDialog::slotParameterProperties()
     UMLAttribute  *pAtt = nullptr, * pOldAtt = nullptr;
 
     int position = m_pParmsLW->row(m_pParmsLW->currentItem());
-    pOldAtt = m_operation->getParmList().at(position);
+    pOldAtt = m_operation->getParameterList().at(position);
     if (!pOldAtt) {
         logDebug1("UMLOperationDialog::slotParameterProperties: The impossible has occurred for: %1",
                   m_pParmsLW->currentItem()->text());
@@ -322,7 +322,7 @@ void UMLOperationDialog::slotParameterProperties()
         bool namingConflict = false;
         QString newName = tempAttribute->name();
 
-        pAtt = m_operation->findParm(newName); // search whether a parameter with this name already exists
+        pAtt = m_operation->findParameter(newName); // search whether a parameter with this name already exists
         if(pAtt && pAtt != pOldAtt) {
             KMessageBox::error(this, i18n("The parameter name you have chosen is already being used in this operation."),
                                i18n("Parameter Name Not Unique"), KMessageBox::Option(0));
@@ -347,9 +347,9 @@ void UMLOperationDialog::slotParameterUp()
     int row = m_pParmsLW->currentRow();
     QListWidgetItem* item = m_pParmsLW->currentItem();
     if (item) {
-        UMLAttribute* pOldAtt = m_operation->getParmList().at(m_pParmsLW->row(item));
+        UMLAttribute* pOldAtt = m_operation->getParameterList().at(m_pParmsLW->row(item));
 
-        m_operation->moveParmLeft(pOldAtt);
+        m_operation->moveParameterLeft(pOldAtt);
         m_pParmsLW->takeItem(row);
         m_pParmsLW->insertItem(row - 1, item);
 
@@ -366,9 +366,9 @@ void UMLOperationDialog::slotParameterDown()
     int row = m_pParmsLW->currentRow();
     QListWidgetItem* item = m_pParmsLW->currentItem();
     if (item) {
-        UMLAttribute* pOldAtt = m_operation->getParmList().at(m_pParmsLW->row(item));
+        UMLAttribute* pOldAtt = m_operation->getParameterList().at(m_pParmsLW->row(item));
 
-        m_operation->moveParmRight(pOldAtt);
+        m_operation->moveParameterRight(pOldAtt);
         m_pParmsLW->takeItem(row);
         m_pParmsLW->insertItem(row + 1, item);
 
@@ -417,7 +417,7 @@ bool UMLOperationDialog::apply()
 
     UMLClassifier *classifier = m_operation->umlParent()->asUMLClassifier();
     if(classifier != nullptr &&
-            classifier->checkOperationSignature(name, m_operation->getParmList(), m_operation))
+            classifier->checkOperationSignature(name, m_operation->getParameterList(), m_operation))
     {
         QString msg = i18n("An operation with that signature already exists in %1.\n", classifier->name())
                       +
