@@ -6,11 +6,11 @@
 #include "objectsmodel.h"
 
 // app includes
-#include "attribute.h"
-#include "classifier.h"
-#include "folder.h"
-#include "operation.h"
-#include "uml.h"
+#include "umlattribute.h"
+#include "umlclassifier.h"
+#include "umlfolder.h"
+#include "umloperation.h"
+#include "umlapp.h"
 #include "umldoc.h"
 
 #include "umlobjectprivate.h"
@@ -21,8 +21,6 @@
 // qt includes
 #include <QtDebug>
 
-Q_DECLARE_METATYPE(UMLObject*);
-
 ObjectsModel::ObjectsModel()
 {
 }
@@ -142,13 +140,13 @@ QVariant ObjectsModel::data(const QModelIndex & index, int role) const
         } else if (o->umlParent()) {
             if (o->isUMLAttribute()) {
                 const UMLOperation *op = o->umlParent()->asUMLOperation();
-                if (op && op->getParmList().contains(o->asUMLAttribute()))
+                if (op && op->getParameterList().contains(o->asUMLAttribute()))
                     return QStringLiteral("parent +");
                 else
                     return QStringLiteral("parent -");
             } else if (o->isUMLOperation()) {
                 const UMLClassifier *c = o->umlParent()->asUMLClassifier();
-                if (c && c->getOpList().contains(o->asUMLOperation()))
+                if (c && c->getOperationsList().contains(o->asUMLOperation()))
                     return QStringLiteral("parent +");
                 else
                     return QStringLiteral("parent -");
