@@ -13,7 +13,7 @@
 #include "docwindow.h"
 #include "listpopupmenu.h"
 #include "statedialog.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlscene.h"
 #include "umlview.h"
