@@ -18,19 +18,18 @@
 #include "portwidget.h"
 #include "preconditionwidget.h"
 #include "regionwidget.h"
-#include "uml.h"
+#include "umlapp.h"
 #include "umldoc.h"
-#include "port.h"
+#include "umlport.h"
 #include "umlscene.h"
 #include "umlwidget.h"
 #include "object_factory.h"
-#include "package.h"
+#include "umlpackage.h"
 #include "widget_factory.h"
 #include "widget_utils.h"
 
 // kde includes
 #include <KLocalizedString>
-#include <KMessageBox>
 
 // qt includes
 
