@@ -7,12 +7,12 @@
 #include "testassociation.h"
 
 // app include
-#include "association.h"
-#include "classifier.h"
-#include "folder.h"
-#include "package.h"
-#include "stereotype.h"
-#include "uml.h"
+#include "umlassociation.h"
+#include "umlclassifier.h"
+#include "umlfolder.h"
+#include "umlpackage.h"
+#include "umlstereotype.h"
+#include "umlapp.h"
 #include "umldoc.h"
 #include "umlobject.h"
 #include "umlrole.h"
@@ -24,9 +24,9 @@
 void TestAssociation::test_equal()
 {
     const SignalBlocker sb(UMLApp::app()->document());
-    UMLPackage parent("Test Parent");
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLPackage parent(QStringLiteral("Test Parent"));
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     a.setUMLPackage(&parent);
     UMLAssociation b(Uml::AssociationType::Association, &o1, &o2);
@@ -43,8 +43,8 @@ void TestAssociation::test_equal()
 
 void TestAssociation::test_toString()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, nullptr);
     QString ar = QString(QStringLiteral("objectA: %1 null")).arg(Uml::AssociationType::toStringI18n(Uml::AssociationType::Association));
     QCOMPARE(a.toString(), ar);
@@ -58,8 +58,8 @@ void TestAssociation::test_toString()
 
 void TestAssociation::test_UMLRole()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QCOMPARE(a.getUMLRole(Uml::RoleType::A)->object(), &o1);
     QCOMPARE(a.getUMLRole(Uml::RoleType::B)->object(), &o2);
@@ -75,8 +75,8 @@ void TestAssociation::test_associationType()
 
 void TestAssociation::test_objectID()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QCOMPARE(a.getObjectId(Uml::RoleType::A), o1.id());
     QCOMPARE(a.getObjectId(Uml::RoleType::B), o2.id());
@@ -84,8 +84,8 @@ void TestAssociation::test_objectID()
 
 void TestAssociation::test_visibility()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QVERIFY(a.visibility(Uml::RoleType::A) == Uml::Visibility::Public);
     QVERIFY(a.visibility(Uml::RoleType::B) == Uml::Visibility::Public);
@@ -106,8 +106,8 @@ void TestAssociation::test_visibility()
 
 void TestAssociation::test_changeability()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QVERIFY(a.visibility(Uml::RoleType::A) == Uml::Visibility::Public);
     QVERIFY(a.visibility(Uml::RoleType::B) == Uml::Visibility::Public);
@@ -130,51 +130,51 @@ void TestAssociation::test_changeability()
 
 void TestAssociation::test_multiplicity()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QCOMPARE(a.getMultiplicity(Uml::RoleType::A), QString());
     QCOMPARE(a.getMultiplicity(Uml::RoleType::B), QString());
-    a.setMultiplicity("1", Uml::RoleType::A);
-    a.setMultiplicity("2", Uml::RoleType::B);
+    a.setMultiplicity(QStringLiteral("1"), Uml::RoleType::A);
+    a.setMultiplicity(QStringLiteral("2"), Uml::RoleType::B);
     QCOMPARE(a.getMultiplicity(Uml::RoleType::A), QStringLiteral("1"));
     QCOMPARE(a.getMultiplicity(Uml::RoleType::B), QStringLiteral("2"));
 }
 
 void TestAssociation::test_roleName()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QCOMPARE(a.getRoleName(Uml::RoleType::A), QString());
     QCOMPARE(a.getRoleName(Uml::RoleType::B), QString());
-    a.setRoleName("test1", Uml::RoleType::A);
-    a.setRoleName("test2", Uml::RoleType::B);
+    a.setRoleName(QStringLiteral("test1"), Uml::RoleType::A);
+    a.setRoleName(QStringLiteral("test2"), Uml::RoleType::B);
     QCOMPARE(a.getRoleName(Uml::RoleType::A), QStringLiteral("test1"));
     QCOMPARE(a.getRoleName(Uml::RoleType::B), QStringLiteral("test2"));
 }
 
 void TestAssociation::test_roleDoc()
 {
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     QCOMPARE(a.getRoleDoc(Uml::RoleType::A), QString());
     QCOMPARE(a.getRoleDoc(Uml::RoleType::B), QString());
-    a.setRoleDoc("test1", Uml::RoleType::A);
-    a.setRoleDoc("test2", Uml::RoleType::B);
+    a.setRoleDoc(QStringLiteral("test1"), Uml::RoleType::A);
+    a.setRoleDoc(QStringLiteral("test2"), Uml::RoleType::B);
     QCOMPARE(a.getRoleDoc(Uml::RoleType::A), QStringLiteral("test1"));
     QCOMPARE(a.getRoleDoc(Uml::RoleType::B), QStringLiteral("test2"));
 }
 
 void TestAssociation::resolveRef()
 {
-    UMLPackage parent("Test Parent");
-    UMLStereotype *stereotype1 = UMLApp::app()->document()->createStereotype("test1");
-    UMLStereotype *stereotype2 = UMLApp::app()->document()->createStereotype("test2");
+    UMLPackage parent(QStringLiteral("Test Parent"));
+    UMLStereotype *stereotype1 = UMLApp::app()->document()->createStereotype(QStringLiteral("test1"));
+    UMLStereotype *stereotype2 = UMLApp::app()->document()->createStereotype(QStringLiteral("test2"));
 
-    UMLObject o1(nullptr, "objectA");
-    UMLObject o2(nullptr, "objectB");
+    UMLObject o1(nullptr, QStringLiteral("objectA"));
+    UMLObject o2(nullptr, QStringLiteral("objectB"));
     UMLAssociation a(Uml::AssociationType::Association, &o1, &o2);
     // no resolve
     a.setUMLPackage(&parent);
@@ -197,17 +197,17 @@ typedef TestUML<UMLAssociation, Uml::AssociationType::Enum> TestUMLAssociation;
 
 void TestAssociation::test_saveAndLoad()
 {
-    UMLPackage parent("Test Parent");
-    UMLClassifier c1("Test A");
-    UMLClassifier c2("Test B");
+    UMLPackage parent(QStringLiteral("Test Parent"));
+    UMLClassifier c1(QStringLiteral("Test A"));
+    UMLClassifier c2(QStringLiteral("Test B"));
     c1.setUMLPackage(&parent);
     c2.setUMLPackage(&parent);
-    c1.setStereotypeCmd("test");
+    c1.setStereotypeCmd(QStringLiteral("test"));
     UMLFolder *root = UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical);
     root->addObject(&c1);
     root->addObject(&c2);
     TestUMLAssociation a1(Uml::AssociationType::Association, &c1, &c2);
-    a1.setNameCmd("Test assoc");
+    a1.setNameCmd(QStringLiteral("Test assoc"));
     a1.setUMLPackage(&parent);
     QString save = a1.testSave1();
     //a1.testDump("save");
